#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-04
# File  : cisco_meraki_org_device_status.py (WATO)

# 2024-06-30: moved power supply part to cisco_meraki_org_device_status_ps.py (shadow built-in file)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersHardware,
)
from cmk.gui.valuespec import (
    Integer,
    Dictionary,
    Tuple,
    MonitoringState,
)


#
# Cisco Meraki Device Status
#
def _parameter_valuespec_cisco_meraki_device_status():
    return Dictionary(
        title=_("Cisco Meraki Device status"),
        optional_keys=True,
        elements=[
            ('last_reported_upper_levels',
             Tuple(
                 title=_('Max time for last reported'),
                 elements=[
                     Integer(title=_('Warning at'), minvalue=0, unit=_('hours'), size=5),
                     Integer(title=_('Critical at'), minvalue=0, unit=_('hours'), size=5),
                 ],
             )),
            ('status_map',
             Dictionary(
                 title=_('Map device status to monitoring state'),
                 elements=[
                     ("online",
                      MonitoringState(
                          title=_('Monitoring state for device state "online"'),
                          default_value=0,
                      )),
                     ("alerting",
                      MonitoringState(
                          title=_('Monitoring state for device state "alerting"'),
                          default_value=2,
                      )),
                     ("offline",
                      MonitoringState(
                          title=_('Monitoring state for device state "offline"'),
                          default_value=1,
                      )),
                     ("dormant",
                      MonitoringState(
                          title=_('Monitoring state for device state "dormant"'),
                          default_value=1,
                      )),
                 ]
             ))
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        title=lambda: _("Cisco Meraki Device status"),
        check_group_name="cisco_meraki_device_status",
        group=RulespecGroupCheckParametersHardware,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_device_status,
        match_type="dict",
    )
)
